@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::str::str_to_isbn10;
 
 our $DATE = '2018-08-23'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -25,12 +25,14 @@ sub coerce {
 
     $res->{expr_match} = "!ref($dt)";
     $res->{modules}{"Algorithm::CheckDigits"} = 0;
+    $res->{modules}{"Algorithm::CheckDigits::M10_004"} = 0;
     $res->{modules}{"Algorithm::CheckDigits::M11_001"} = 0;
     $res->{expr_coerce} = join(
         "",
         "do { my \$digits = $dt; \$digits =~ s/[^0-9Xx]//g; \$digits = uc \$digits; ",
         "my \$res; ",
         "{ ",
+        "  if (length \$digits == 13) { if (substr(\$digits, 0, 3) ne '978') { \$res = ['Can only convert from ISBN 13 with 978 prefix']; last } \$digits = Algorithm::CheckDigits::CheckDigits('ISBN')->complete(substr(\$digits, 3, 9)); \$res = [undef, \$digits]; last } ", # convert from ISBN 13
         "  if (length \$digits != 10) { \$res = ['ISBN 10 must have 10 digits']; last } ",
         "  unless (Algorithm::CheckDigits::CheckDigits('ISBN')->is_valid(\$digits)) { \$res = ['Invalid checksum digit']; last } ",
         "  \$res = [undef, \$digits]; ",
@@ -56,7 +58,7 @@ Data::Sah::Coerce::perl::str::str_to_isbn10 - Check and format ISBN 10 number fr
 
 =head1 VERSION
 
-This document describes version 0.001 of Data::Sah::Coerce::perl::str::str_to_isbn10 (from Perl distribution Sah-Schemas-ISBN), released on 2018-08-23.
+This document describes version 0.002 of Data::Sah::Coerce::perl::str::str_to_isbn10 (from Perl distribution Sah-Schemas-ISBN), released on 2018-08-23.
 
 =head1 DESCRIPTION
 
